@@ -1,4 +1,4 @@
-use crate::models::identifiers::{Identifier, OpenLibraryIdentifer};
+use crate::models::identifiers::{Identifier, OpenLibraryIdentifier};
 use crate::models::works::Work;
 use crate::OpenLibraryClient;
 use reqwest::{Method, Url};
@@ -14,7 +14,7 @@ async fn test_works_get_returns_success() -> Result<(), Box<dyn Error>> {
         .with_host(Url::parse(server.uri().as_str())?)
         .build()?;
 
-    let mock_work_identifier = OpenLibraryIdentifer::from_str("OL92304270")?;
+    let mock_work_identifier = OpenLibraryIdentifier::from_str("OL92304270")?;
     let mock_response: Work = serde_json::from_str(include_str!("resources/work.json"))?;
 
     Mock::given(method(Method::GET.as_str()))
@@ -31,3 +31,5 @@ async fn test_works_get_returns_success() -> Result<(), Box<dyn Error>> {
     assert_eq!(actual, mock_response);
     Ok(())
 }
+
+//TODO write a test for the different options for field values (Author Type)
