@@ -70,9 +70,9 @@ pub mod date_m_dd_yyyy {
     }
 }
 
-#[derive(Deserialize, Serialize)]
-struct KeyedValue<T> {
-    key: T,
+#[derive(Debug, Deserialize, Eq, PartialEq, Serialize)]
+pub struct KeyedValue<T> {
+    pub key: T,
 }
 
 pub mod keyed_value {
@@ -122,3 +122,29 @@ pub mod keyed_list {
         Ok(x1)
     }
 }
+
+//TODO: convert into Tagged OpenLibraryTyped Enum
+pub mod value {
+    use serde::{Deserialize, Deserializer, Serialize, Serializer};
+
+    #[derive(Deserialize, Serialize)]
+    struct TypedValue<T> {
+        value: T,
+    }
+
+    pub fn serialize<S, T>(value: T, serializer: S) -> Result<S::Ok, S::Error>
+    where
+        S: Serializer,
+        T: Serialize,
+    {
+        TypedValue { value }.serialize(serializer)
+    }
+
+    pub fn deserialize<'de, D, T>(deserializer: D) -> Result<Option<T>, D::Error>
+    where
+        D: Deserializer<'de>,
+        T: Deserialize<'de>,
+    {
+        Ok(Some(TypedValue::deserialize(deserializer)?.value))
+    }
+}
