@@ -1,6 +1,8 @@
+use crate::models::identifiers::OpenLibraryIdentifier;
 use serde::de::Error;
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
 use std::fmt::{Display, Formatter};
+use std::str::FromStr;
 
 pub mod account;
 pub mod authors;
@@ -12,22 +14,29 @@ pub mod works;
 mod tests;
 
 #[derive(Clone, Debug, Eq, PartialEq)]
-pub enum Resource {
+pub enum OpenLibraryResource {
     Author(String),
     Book(String),
     Work(String),
 }
-//
-pub trait OpenLibraryModel {}
-pub trait OpenLibraryIdentifierKey {}
-impl OpenLibraryIdentifierKey for Resource {}
 
-impl Display for Resource {
+impl OpenLibraryResource {
+    pub fn value(&self) -> String {
+        match self {
+            OpenLibraryResource::Author(value) => value,
+            OpenLibraryResource::Book(value) => value,
+            OpenLibraryResource::Work(value) => value,
+        }
+        .clone()
+    }
+}
+
+impl Display for OpenLibraryResource {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         let x = match self {
-            Resource::Author(value) => format!("/authors/{}", value),
-            Resource::Book(value) => format!("/books/{}", value),
-            Resource::Work(value) => format!("/works/{}", value),
+            OpenLibraryResource::Author(value) => format!("/authors/{}", value),
+            OpenLibraryResource::Book(value) => format!("/books/{}", value),
+            OpenLibraryResource::Work(value) => format!("/works/{}", value),
         };
 
         write!(f, "{}", x)?;
@@ -35,7 +44,7 @@ impl Display for Resource {
     }
 }
 
-impl<'de> Deserialize<'de> for Resource {
+impl<'de> Deserialize<'de> for OpenLibraryResource {
     fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
     where
         D: Deserializer<'de>,
@@ -64,15 +73,15 @@ impl<'de> Deserialize<'de> for Resource {
         }?;
 
         match resource {
-            "authors" => Ok(Resource::Author(identifier.to_string())),
-            "books" => Ok(Resource::Book(identifier.to_string())),
-            "works" => Ok(Resource::Work(identifier.to_string())),
+            "authors" => Ok(OpenLibraryResource::Author(identifier.to_string())),
+            "books" => Ok(OpenLibraryResource::Book(identifier.to_string())),
+            "works" => Ok(OpenLibraryResource::Work(identifier.to_string())),
             _ => Err(D::Error::custom("Could not parse into Resource")),
         }
     }
 }
 
-impl Serialize for Resource {
+impl Serialize for OpenLibraryResource {
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
     where
         S: Serializer,
@@ -80,3 +89,28 @@ impl Serialize for Resource {
         serializer.serialize_str(self.to_string().as_str())
     }
 }
+
+impl From<OpenLibraryResource> for OpenLibraryIdentifier {
+    fn from(resource: OpenLibraryResource) -> Self {
+        Self::from_str(&resource.value()).unwrap()
+    }
+}
+
+#[derive(Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
+pub struct Link {
+    #[serde(skip_serializing_if = "String::is_empty")]
+    url: String,
+    #[serde(skip_serializing_if = "String::is_empty")]
+    title: String,
+}
+
+#[derive(Clone, Deserialize, Debug, Eq, Hash, PartialEq, Serialize)]
+#[serde(rename_all = "lowercase")]
+pub enum LinkName {
+    Author,
+    #[serde(rename = "self")]
+    Itself,
+    Next,
+}
+
+pub trait OpenLibraryModel {}
