@@ -1,4 +1,4 @@
-use crate::models::{OpenLibraryIdentifierKey, OpenLibraryModel, Resource};
+use crate::models::{Link, OpenLibraryModel, OpenLibraryResource};
 use crate::OpenLibraryError;
 use serde::de::Error;
 use serde::{Deserialize, Deserializer, Serialize};
@@ -13,7 +13,7 @@ pub struct Book {
     #[serde(deserialize_with = "url_or_list")]
     #[serde(skip_serializing_if = "Vec::is_empty")]
     pub url: Vec<Url>,
-    pub key: Resource,
+    pub key: OpenLibraryResource,
     pub title: String,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub subtitle: Option<String>,
@@ -184,8 +184,6 @@ impl BookIdentifierKey {
     }
 }
 
-impl OpenLibraryIdentifierKey for BookIdentifierKey {}
-
 impl Display for BookIdentifierKey {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
@@ -226,14 +224,16 @@ impl FromStr for BookIdentifierKey {
     }
 }
 
+//TODO: this is a duplicate struct name
+// and also wrong
 #[derive(Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
 pub struct Author {
     #[serde(skip_serializing_if = "Option::is_none")]
-    key: Option<Resource>,
+    pub key: Option<OpenLibraryResource>,
     #[serde(skip_serializing_if = "Option::is_none")]
-    name: Option<String>,
+    pub name: Option<String>,
     #[serde(skip_serializing_if = "Option::is_none")]
-    url: Option<String>,
+    pub url: Option<String>,
 }
 
 #[derive(Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
@@ -273,14 +273,6 @@ pub struct Excerpt {
     text: String,
 }
 
-#[derive(Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
-pub struct Link {
-    #[serde(skip_serializing_if = "String::is_empty")]
-    url: String,
-    #[serde(skip_serializing_if = "String::is_empty")]
-    title: String,
-}
-
 // Necessary since the `publishers` field can either be Vec<String> or Vec<Entity> based on the endpoint
 // Book Search:
 //    "publishers": [
